References
--------------

.. [Adams2017] `Journal of Machine Learning Research 18 (2017) 1-35
    <https://jmlr.csail.mit.edu/papers/volume18/16-337/16-337.pdf>`_

.. [Perea] `Jose A. Perea, Elizabeth Munch, Firas A. Khasawneh, Approximating
    Continuous Functions on Persistence Diagrams Using Template Functions,
    arXiv:1902.07190 <https://arxiv.org/abs/1902.07190>`_

.. [Tymochko] `Sarah Tymochko, Elizabeth Munch, Firas A. Khasawneh, Adaptive
    Partitioning for Template Functions on Persistence Diagrams,
    arXiv:1910.08506v1 <https://arxiv.org/abs/1910.08506v1>`_

.. [Moosavi2021] `Moosavi et al., Nature Communications 2021
    <https://www.nature.com/articles/s41467-020-17755-8>`_

.. [Fernandez2013] `Fernandez et al., J. Phys. Chem. C. 2013
    <https://pubs.acs.org/doi/full/10.1021/jp404287t>`_

.. [Bucior2019] `Bucior et al.,  Mol. Syst. Des. Eng. 2019
    <https://pubs.rsc.org/en/content/articlelanding/2019/me/c8me00050f>`_

.. [Willems2011] `Willems et al., Microporous and Mesoporous Materials, 149
    (2012) 134-141
    <http://www.sciencedirect.com/science/article/pii/S1387181111003738>`_

.. [Pinheiro2013] `Pinheiro et al., Journal of Molecular Graphics and Modeling
    2013, 44, 208-219
    <http://www.sciencedirect.com/science/article/pii/S109332631300096X?via%3Dihub>`_

.. [Ongari2017] `Ongari et al., Langmuir 2017, 33, 14529-14538
    <https://pubs.acs.org/doi/10.1021/acs.langmuir.7b016824>`_

.. [Krishnapriyan2020] `Krishnapriyan et al., J. Phys. Chem. C 2020, 124,
    9360–9368 <https://www.nature.com/articles/s41598-021-88027-8>`_

.. [Krishnapriyan2021] `Krishnapriyan et al., Scientific Reports 2021, 11, 8888
    <https://www.nature.com/articles/s41598-021-88027-8>`_

.. [Janet2017] `Janet, J. P.; Kulik, H. J. J. Phys. Chem. A 2017, 121 (46),
    8939–8954 <https://doi.org/10.1021/acs.jpca.7b08750>`_

.. [Ongari2019] `Ongari et al., J. Chem. Theory Comput. 2019, 15, 1, 382–401 <http://pubs.acs.org/doi/10.1021/acs.jctc.8b00669>`_

.. [Wilmer2012] `Wilmer et al., J. Phys. Chem. Lett. 2012, 3, 17, 2506–2511
    <https://pubs.acs.org/doi/abs/10.1021/jz3008485>`_

.. [Jiang2021] `Jiang, Y.; Chen, D.; Chen, X.; Li, T.; Wei, G.-W.; Pan, F.
    Topological Representations of Crystalline Compounds for the
    Machine-Learning Prediction of Materials Properties. npj Computational
    Materials 2021, 7 (1), 1–8. <https://doi.org/10.1038/s41524-021-00493-w>`_

.. [Widdowson2022] `Widdowson et al. Average minimum distances of periodic point
    sets – foundational invariants for mapping periodic crystals. MATCH
    Communications in Mathematical and in Computer Chemistry, 87(3), 529-559
    (2022). <https://doi.org/10.46793/match.87-3.529W>`_

.. [Hung2022] `Hung, T.-H.; Xu, Z.-X.; Kang, D.-Y.; Lin, L.-C. Chemistry-Encoded Convolutional Neural Networks for Predicting Gaseous Adsorption in Porous Materials. The Journal of Physical Chemistry C, 2022, 126, 2813–2822. <https://doi.org/10.1021/acs.jpcc.1c09649>`_

.. [Cho2021] `Cho, E. H.; Lin, L.-C. Nanoporous Material Recognition via 3D Convolutional Neural Networks: Prediction of Adsorption Properties. The Journal of Physical Chemistry Letters, 2021, 12, 2279–2285. <https://doi.org/10.1021/acs.jpclett.1c00293>`_

.. [Dubbeldam] `Dubbeldam, D.; Calero, S.; Ellis, D. E.; Snurr, R. Q. RASPA: Molecular Simulation Software for Adsorption and Diffusion in Flexible Nanoporous Materials. Molecular Simulation, 2015, 42, 81–101. <https://doi.org/10.1080/08927022.2015.1010082>`_

.. [AMD] `Widdowson, D.; Mosca, M. M.; Pulido, A.; Cooper, A. I.; Kurlin, V. Average Minimum Distances of Periodic Point Sets – Foundational Invariants for Mapping Periodic Crystals. MATCH Communications in Mathematical and in Computer Chemistry, 2021, 87, 529–559. <https://doi.org/10.46793/match.87-3.529w>`_

.. [PDD] `Widdowson, D.; Kurlin, V. Pointwise Distance Distributions of Periodic Point Sets. arXiv 2021. <https://doi.org/10.48550/ARXIV.2108.04798>`_

.. [Wirth] `Wirth, M.; Volkamer, A.; Zoete, V.; Rippmann, F.; Michielin, O.; Rarey, M.; Sauer, W. H. B. Protein Pocket and Ligand Shape Comparison and Its Application in Virtual Screening. Journal of Computer-Aided Molecular Design, 2013, 27, 511–524. <https://doi.org/10.1007/s10822-013-9659-1>`_

.. [Zhang2022] `Zhang, R.; Seth, S.; Cumby, J. Grouped Representation of Interatomic Distances as a Similarity Measure for Crystal Structures. 2022. <https://doi.org/10.26434/chemrxiv-2022-9m4jh>`_

.. [WL] `B. Weisfeiler, A. Lehman, The reduction of a graph to canonical form and the algebra which appears therein, 1968 (English translation) <https://www.iti.zcu.cz/wl2018/pdf/wl_paper_translation.pdf>`_

.. [Bouritsas] `Bouritsas, G.; Frasca, F.; Zafeiriou, S.; Bronstein, M. M. Improving Graph Neural Network Expressivity via Subgraph Isomorphism Counting. arXiv 2020. <https://doi.org/10.48550/ARXIV.2006.09252>`_

.. [MoleculeNet] `Wu, Z.; Ramsundar, B.; Feinberg, E. N.; Gomes, J.; Geniesse, C.; Pappu, A. S.; Leswing, K.; Pande, V. MoleculeNet: A Benchmark for Molecular Machine Learning. Chemical Science 2018, 9 (2), 513–530 <https://doi.org/10.1039/c7sc02664a>`_

.. [Palizhati] `Palizhati, A.; Torrisi, S. B.; Aykol, M.; Suram, S. K.; Hummelshøj, J. S.; Montoya, J. H. Agents for Sequential Learning Using Multiple-Fidelity Data. Scientific Reports 2022, 12 (1). <https://doi.org/10.1038/s41598-022-08413-8>`_

.. [Sheridan] `Sheridan, R. P. Time-Split Cross-Validation as a Method for Estimating the Goodness of Prospective Prediction. Journal of Chemical Information and Modeling 2013, 53 (4), 783–790. <https://doi.org/10.1021/ci400084k>`_

.. [KennardStone] `R. W. Kennard & L. A. Stone (1969): Computer Aided Design of Experiments,
    Technometrics, 11:1, 137-148.
    <https://www.tandfonline.com/doi/abs/10.1080/00401706.1969.10490666>`_

.. [Snee] Snee, R.D., 1977. Validation of regression models: methods and examples.
    Technometrics 19, 415-428.

.. [Kramer] `Kramer, C.; Gedeck, P. Leave-Cluster-Out Cross-Validation
    Is Appropriate for Scoring Functions Derived from Diverse Protein Data Sets.
    Journal of Chemical Information and Modeling, 2010, 50, 1961–1969.
    <https://doi.org/10.1021/ci100264e>`_

.. [Meredig] `Meredig, B.; Antono, E.; Church, C.; Hutchinson, M.; Ling, J.; Paradiso,
    S.; Blaiszik, B.; Foster, I.; Gibbons, B.; Hattrick-Simpers, J.; Mehta, A.; Ward, L.
    Can Machine Learning Identify the next High-Temperature Superconductor?
    Examining Extrapolation Performance for Materials Discovery.
    Molecular Systems Design &amp; Engineering, 2018, 3, 819–825.
    <https://doi.org/10.1039/c8me00012c>`_

.. [Kapoor] `Kapoor, S.; Narayanan, A. Leakage and the Reproducibility Crisis in ML-Based Science. arXiv July 14, 2022. <http://arxiv.org/abs/2207.07048>`_

.. [Malik] `Malik, M. M. A Hierarchy of Limitations in Machine Learning. arXiv February 29, 2020. <http://arxiv.org/abs/2002.05193>`_

.. [Lones] `Lones, M. A. How to Avoid Machine Learning Pitfalls: A Guide for Academic Researchers. arXiv August 5, 2021.<http://arxiv.org/abs/2108.02497>`

.. [Raschka] `Raschka, S. Model Evaluation, Model Selection, and Algorithm Selection in Machine Learning. arXiv:1811.12808 [cs, stat] 2018. <https://arxiv.org/abs/1811.12808>`_

.. [UFF] `Rappe, A. K.; Casewit, C. J.; Colwell, K. S.; Goddard, W. A.; Skiff, W. M. UFF, a Full Periodic Table Force Field for Molecular Mechanics and Molecular Dynamics Simulations. Journal of the American Chemical Society 1992, 114 (25), 10024–10035. <https://doi.org/10.1021/ja00051a040>`_

.. [Trappe] `Potoff, J. J.; Siepmann, J. I. Vapor–Liquid Equilibria of Mixtures Containing Alkanes, Carbon Dioxide, and Nitrogen. AIChE Journal 2001, 47 (7), 1676–1682. <https://doi.org/10.1002/aic.690470719>`_

.. [Varoquaux] `Varoquaux, G. Cross-Validation Failure: Small Sample Sizes Lead to Large Error Bars. NeuroImage 2018, 180, 68–77. <https://doi.org/10.1016/j.neuroimage.2017.06.061>`_
